==> libreoffice-4.4.5.2.tar.xz: libreoffice-4.4.5.2/fpicker/source/aqua/NSString_OOoAdditions.mm <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "CFStringUtilities.hxx"
#include "NSString_OOoAdditions.hxx"

#define CLASS_NAME "NSString"

@implementation NSString (OOoAdditions) 

+ (id) stringWithOUString:(const rtl::OUString&)ouString
{
    DBG_PRINT_ENTRY(CLASS_NAME, __func__, "ouString", ouString);

    NSString *string = [[NSString alloc] initWithCharacters:ouString.getStr() length:ouString.getLength()];

    DBG_PRINT_EXIT(CLASS_NAME, __func__, string);
    return [string autorelease];
}

- (rtl::OUString) OUString
{
    unsigned int nFileNameLength = [self length];

    UniChar unichars[nFileNameLength+1];

    //'close' the string buffer correctly
    unichars[nFileNameLength] = '\0';

    [self getCharacters:unichars];

    return rtl::OUString(unichars);
}

@end

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_5.1.6~rc2.orig.tar.xz: libreoffice-5.1.6~rc2/fpicker/source/aqua/NSString_OOoAdditions.mm <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "CFStringUtilities.hxx"
#include "NSString_OOoAdditions.hxx"

#define CLASS_NAME "NSString"

@implementation NSString (OOoAdditions) 

+ (id) stringWithOUString:(const rtl::OUString&)ouString
{
    DBG_PRINT_ENTRY(CLASS_NAME, __func__, "ouString", ouString);

    NSString *string = [[NSString alloc] initWithCharacters:reinterpret_cast<unichar const *>(ouString.getStr()) length:ouString.getLength()];

    DBG_PRINT_EXIT(CLASS_NAME, __func__, string);
    return [string autorelease];
}

- (rtl::OUString) OUString
{
    unsigned int nFileNameLength = [self length];

    UniChar unichars[nFileNameLength+1];

    //'close' the string buffer correctly
    unichars[nFileNameLength] = '\0';

    [self getCharacters:unichars];

    return rtl::OUString(reinterpret_cast<sal_Unicode *>(unichars));
}

@end

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
